@@ -23,6 +23,7 @@
 #include "Document.h"
 #include "DocumentManager.h"
 
+#include <KLocale>
 #include <KDebug>
 #include <QAction>
 #include <QScriptEngineDebugger>
@@ -65,7 +66,6 @@ public:
 };
 
 
-
 static QScriptValue debug_script(QScriptContext* context, QScriptEngine* /*engine*/)
 {
     DocumentManager::self().activeDocument()->engineBackend()->debug(QString("%1").arg(context->argument(0).toString()));
@@ -91,8 +91,6 @@ static QScriptValue include_script(QScriptContext *context, QScriptEngine* /*eng
     return QScriptValue();
 }
 
-
-
 QtScriptBackend::QtScriptBackend(QObject* parent)
     : QObject(parent)
     , d(new QtScriptBackendPrivate)
@@ -172,20 +170,23 @@ QString QtScriptBackend::execute()
     int size = d->_document->dataStructures().size();
     for (int i = 0; i < size; i++) {
         d->_document->dataStructures().at(i)->setEngine(d->_engine);
+        connect(d->_document->dataStructures().at(i).get(), SIGNAL(scriptError(QString)), this, SIGNAL(scriptError(QString)));
     }
     d->createGraphList();
     d->_engine->setProcessEventsInterval(100); //! TODO: Make that changeable.
 
     QString result = d->_engine->evaluate(d->_currentScript, i18n("Rocs Console script")).toString();
     if (d->_engine && d->_engine->hasUncaughtException()) {
-        emit scriptError();
-        emit sendDebug("<b style=\"color: red\">" + result + "</b>");
-        emit sendDebug("<b style=\"color: red\">" + d->_engine->uncaughtExceptionBacktrace().join("\n") + "</b>");
+        emit scriptError(i18n("Script Error: %1", result));
+        emit scriptError(d->_engine->uncaughtExceptionBacktrace().join("\n"));
     }
     if (d->_engine) {
+        emit scriptInfo(i18nc("@info status message after successful script execution", "<i>Execution Finished</i>"));
         d->_engine->popContext();
+        for (int i = 0; i < size; i++) {
+            d->_document->dataStructures().at(i).get()->disconnect(this);
+        }
     }
-    output(i18nc("@info status message after successful script execution", "<i>Execution Finished</i>"));
     emit finished();
     return result;
 }
@@ -213,19 +214,23 @@ void QtScriptBackend::executeStep()
         int size = d->_document->dataStructures().size();
         for (int i = 0; i < size; i++) {
             d->_document->dataStructures().at(i)->setEngine(d->_engine);
+            connect(d->_document->dataStructures().at(i).get(), SIGNAL(scriptError(QString)), this, SIGNAL(scriptError(QString)));
         }
         d->createGraphList();
         d->_engine->setProcessEventsInterval(100);
 
         QString error = d->_engine->evaluate(d->_currentScript).toString();
         if (d->_engine && d->_engine->hasUncaughtException()) {
-            emit scriptError();
-            emit sendDebug("<b style=\"color: red\">" + error + "</b>");
+            emit scriptError(i18n("Script Error: %1", error));
         }
     }
 
     if (!d->_engine || !d->_engine->isEvaluating()) {
-        output(i18nc("@info status message after successful script execution", "<i>Execution Finished</i>"));
+        scriptInfo(i18nc("@info status message after successful script execution", "<i>Execution Finished</i>"));
+        int size = d->_document->dataStructures().size();
+        for (int i = 0; i < size; i++) {
+            d->_document->dataStructures().at(i).get()->disconnect(this);
+        }
         emit finished();
     }
 }
@@ -242,16 +247,17 @@ void QtScriptBackend::setScript(const QString& s, Document *graphs)
 {
     d->_currentScript = s;
     d->_document = graphs;
-    kDebug() << "script Set" << d->_currentScript;
 }
 
 void QtScriptBackend::debug(const QString& message)
 {
-    emit sendDebug("<b>" + message + "</b>");
+    emit scriptError(i18n("The global method \"%1\" is deprecated, please use \"%2\" instead.", QString("debug(message)"), QString("Console.debug(message)")));
+    emit sendDebug(message);
 }
 
 void QtScriptBackend::output(const QString& message)
 {
+    emit scriptError(i18n("The global method \"%1\" is deprecated, please use \"%2\" instead.", QString("output(message)"), QString("Console.log(message)")));
     emit sendOutput(message);
     emit sendDebug(message);
 }
@@ -278,10 +284,8 @@ void QtScriptBackend::include(const QString& filePath)
         d->_engine->currentContext()->setActivationObject(d->_engine->currentContext()->parentContext()->activationObject());
         QString error = d->_engine->evaluate(script, filePath).toString();
         if (d->_engine && d->_engine->hasUncaughtException()) {
-            emit scriptError();
-            emit sendDebug(i18n("<b style=\"color: red\"> Error in include file %1</b>", filePath));
-            emit sendDebug("<b style=\"color: red\">" + error + "</b>");
-            emit sendDebug("<b style=\"color: red\">" + d->_engine->uncaughtExceptionBacktrace().join("\n") + "</b>");
+            emit scriptError(i18n("Script error in included file %1", filePath));
+            emit scriptError(d->_engine->uncaughtExceptionBacktrace().join("\n"));
         }
     }
 }
